@@ -71,6 +71,12 @@ def _standard_cli_parser(doc: str, fixer: bool):
             default=False,
             help="Show the lines which were changed",
         )
+    parser.add_argument(
+        "-v", "--verbose", action="count", help="Increase output verbosity", default=0
+    )
+    parser.add_argument(
+        "-q", "--quiet", action="count", help="Decrease output verbosity", default=0
+    )
     parser.add_argument(
         "--color",
         type=str.lower,
@@ -100,6 +106,8 @@ def parse_cli_args(
         argv = sys.argv[1:]
     args = parser.parse_args(argv)
 
+    args.verbosity = 1 + args.verbose - args.quiet
+
     if postprocess:
         args = postprocess(args)
     return args
